References
----------
aligo_asd
  `LIGO Document T1800044-v5 <https://dcc.ligo.org/LIGO-T1800044/public>`_
etd_asd
  `ET sensitivities page <http://www.et-gw.eu/index.php/etsensitivities>`_
lisa_asd
  `SciRD curve from arXiv:2108.01167 <https://arxiv.org/abs/2108.01167>`_
ce_asd
  `Cosmic Explorer Sensitivity Curves <https://dcc.cosmicexplorer.org/CE-T2000017/public>`_
unofficial_asd
  `Unofficial sensitivity curves (ASD) for aLIGO, KAGRA, Virgo, Voyager, Cosmic Explorer, and Einstein Telescope, LIGO Document T1500293-v13 <https://dcc.ligo.org/LIGO-T1500293/public>`_
